pub struct StorageBuffer<T, Mut: Mutability> { /* private fields */ }Expand description
A storage buffer is a buffer that can be read from or written to in the shader
Implementations
Sourceimpl<T: ShaderType + WriteInto + CreateFrom, Mut: Mutability> StorageBuffer<T, Mut>
impl<T: ShaderType + WriteInto + CreateFrom, Mut: Mutability> StorageBuffer<T, Mut>
Sourcepub fn upload_shrink(&self, data: &T)
pub fn upload_shrink(&self, data: &T)
Uploads data into the buffer, reallocating to the minimum needed buffer size.
Sourcepub fn download(&self) -> T
pub fn download(&self) -> T
Downloads the buffer from the GPU in a blocking manner. This can be pretty slow.
Sourcepub fn download_async(&self, func: impl FnOnce(T) + Send + 'static)
pub fn download_async(&self, func: impl FnOnce(T) + Send + 'static)
Requests the download of the buffer. The provided callback will be executed once the transfer finishes.